@@ -94,14 +94,27 @@ class ProxyLoggingMiddleware(object):
     def __init__(self, app, conf):
         self.app = app
         self.log_hdrs = conf.get('log_headers', 'no').lower() in TRUE_VALUES
+
+        # The leading access_* check is in case someone assumes that
+        # log_statsd_valid_http_methods behaves like the other log_statsd_*
+        # settings.
+        self.valid_methods = conf.get(
+            'access_log_statsd_valid_http_methods',
+            conf.get('log_statsd_valid_http_methods',
+                     'GET,HEAD,POST,PUT,DELETE,COPY'))
+        self.valid_methods = [m.strip().upper() for m in
+                              self.valid_methods.split(',') if m.strip()]
         access_log_conf = {}
         for key in ('log_facility', 'log_name', 'log_level', 'log_udp_host',
-                    'log_udp_port'):
+                    'log_udp_port', 'log_statsd_host', 'log_statsd_port',
+                    'log_statsd_default_sample_rate',
+                    'log_statsd_metric_prefix'):
             value = conf.get('access_' + key, conf.get(key, None))
             if value:
                 access_log_conf[key] = value
         self.access_logger = get_logger(access_log_conf,
-                        log_route='proxy-access')
+                                        log_route='proxy-access')
+        self.access_logger.set_statsd_prefix('proxy-server')
 
     def log_request(self, env, status_int, bytes_received, bytes_sent,
                     request_time, client_disconnect):
@@ -117,20 +130,22 @@ class ProxyLoggingMiddleware(object):
         req = Request(env)
         if client_disconnect:  # log disconnected clients as '499' status code
             status_int = 499
-        req_path = get_valid_utf8_str(env.get('PATH_INFO', ''))
+        req_path = get_valid_utf8_str(req.path)
         the_request = quote(unquote(req_path))
         if req.query_string:
             the_request = the_request + '?' + req.query_string
         logged_headers = None
         if self.log_hdrs:
             logged_headers = '\n'.join('%s: %s' % (k, v)
-                for k, v in req.headers.items())
-        self.access_logger.info(' '.join(quote(str(x) if x else '-')
+                                       for k, v in req.headers.items())
+        method = req.environ.get('swift.orig_req_method', req.method)
+        self.access_logger.info(' '.join(
+            quote(str(x) if x else '-')
             for x in (
                 get_remote_client(req),
                 req.remote_addr,
                 time.strftime('%d/%b/%Y/%H/%M/%S', time.gmtime()),
-                req.method,
+                method,
                 the_request,
                 req.environ.get('SERVER_PROTOCOL'),
                 status_int,
@@ -145,7 +160,25 @@ class ProxyLoggingMiddleware(object):
                 '%.4f' % request_time,
                 req.environ.get('swift.source'),
             )))
-        self.access_logger.txn_id = None
+        # Log timing and bytes-transfered data to StatsD
+        if req.path.startswith('/v1/'):
+            try:
+                stat_type = [None, 'account', 'container',
+                             'object'][req.path.strip('/').count('/')]
+            except IndexError:
+                stat_type = 'object'
+        else:
+            stat_type = env.get('swift.source')
+        # Only log data for valid controllers (or SOS) to keep the metric count
+        # down (egregious errors will get logged by the proxy server itself).
+        if stat_type:
+            stat_method = method if method in self.valid_methods \
+                else 'BAD_METHOD'
+            metric_name = '.'.join((stat_type, stat_method, str(status_int)))
+            self.access_logger.timing(metric_name + '.timing',
+                                      request_time * 1000)
+            self.access_logger.update_stats(metric_name + '.xfer',
+                                            bytes_received + bytes_sent)
 
     def __call__(self, env, start_response):
         start_response_args = [None]
@@ -175,8 +208,8 @@ class ProxyLoggingMiddleware(object):
                         ('content-length', str(sum(len(i) for i in iterable))))
                 else:
                     raise Exception('WSGI [proxy-logging]: No content-length '
-                        'or transfer-encoding header sent and there is '
-                        'content! %r' % chunk)
+                                    'or transfer-encoding header sent and '
+                                    'there is content! %r' % chunk)
             start_response(*start_response_args[0])
             bytes_sent = 0
             client_disconnect = False
@@ -190,16 +223,17 @@ class ProxyLoggingMiddleware(object):
                 raise
             finally:
                 status_int = int(start_response_args[0][0].split(' ', 1)[0])
-                self.log_request(env, status_int,
-                        input_proxy.bytes_received, bytes_sent,
-                        time.time() - start_time,
-                        client_disconnect or input_proxy.client_disconnect)
+                self.log_request(
+                    env, status_int, input_proxy.bytes_received, bytes_sent,
+                    time.time() - start_time,
+                    client_disconnect or input_proxy.client_disconnect)
 
         try:
             iterable = self.app(env, my_start_response)
         except Exception:
-            self.log_request(env, 500, input_proxy.bytes_received, 0,
-                    time.time() - start_time, input_proxy.client_disconnect)
+            self.log_request(
+                env, 500, input_proxy.bytes_received, 0,
+                time.time() - start_time, input_proxy.client_disconnect)
             raise
         else:
             return iter_response(iterable)
