@@ -16,7 +16,7 @@ import eventlet
 from webob import Request, Response
 
 from swift.common.utils import split_path, cache_from_env, get_logger
-from swift.proxy.server import get_container_memcache_key
+from swift.proxy.controllers.base import get_container_memcache_key
 from swift.common.memcached import MemcacheConnectionError
 
 
@@ -118,7 +118,8 @@ class RateLimitMiddleware(object):
                                                       container_name)
             container_info = self.memcache_client.get(memcache_key)
             if isinstance(container_info, dict):
-                container_size = container_info.get('container_size', 0)
+                container_size = container_info.get(
+                    'count', container_info.get('container_size', 0))
                 container_rate = self.get_container_maxrate(container_size)
                 if container_rate:
                     keys.append(("ratelimit/%s/%s" % (account_name,
