@@ -126,7 +126,11 @@ def get_param(req, name, default=None):
 
 class FallocateWrapper(object):
 
-    def __init__(self):
+    def __init__(self, noop=False):
+        if noop:
+            self.func_name = 'posix_fallocate'
+            self.fallocate = noop_libc_function
+            return
         ## fallocate is prefered because we need the on-disk size to match
         ## the allocated size. Older versions of sqlite require that the
         ## two sizes match. However, fallocate is Linux only.
@@ -147,6 +151,11 @@ class FallocateWrapper(object):
         return self.fallocate(*args[self.func_name])
 
 
+def disable_fallocate():
+    global _sys_fallocate
+    _sys_fallocate = FallocateWrapper(noop=True)
+
+
 def fallocate(fd, size):
     """
     Pre-allocate disk space for a file.
@@ -552,9 +561,11 @@ def get_logger(conf, name=None, log_to_console=False, log_route=None,
         log_name = swift
         log_udp_host = (disabled)
         log_udp_port = logging.handlers.SYSLOG_UDP_PORT
+        log_address = /dev/log
         log_statsd_host = (disabled)
         log_statsd_port = 8125
         log_statsd_default_sample_rate = 1
+        log_statsd_metric_prefix = (empty-string)
 
     :param conf: Configuration dict to read settings from
     :param name: Name of the logger
@@ -593,7 +604,8 @@ def get_logger(conf, name=None, log_to_console=False, log_route=None,
         try:
             handler = SysLogHandler(address=log_address, facility=facility)
         except socket.error, e:
-            if e.errno != errno.ENOTSOCK:  # Socket operation on non-socket
+            # Either /dev/log isn't a UNIX socket or it does not exist at all
+            if e.errno not in [errno.ENOTSOCK,  errno.ENOENT]:
                 raise e
             handler = SysLogHandler(facility=facility)
     handler.setFormatter(formatter)
